==> nivo-0.2.0.tgz: package/es/components/charts/line/Line.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { merge } from 'lodash-es';
import { line } from 'd3';
import Nivo, { defaultTheme } from '../../../Nivo';
import { margin as marginPropType, motion as motionPropTypes } from '../../../PropTypes';
import { getColorsGenerator, getColorGenerator } from '../../../ColorUtils';
import SvgWrapper from '../SvgWrapper';
import { generateLines, generateStackedLines } from '../../../lib/charts/line';
import { curvePropMapping, curvePropType } from '../../../properties/curve';
import Axes from '../../axes/Axes';
import Grid from '../../axes/Grid';
import LineMarkers from './LineMarkers';

var Line = function (_Component) {
    _inherits(Line, _Component);

    function Line() {
        _classCallCheck(this, Line);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    Line.prototype.render = function render() {
        var _props = this.props,
            data = _props.data,
            stacked = _props.stacked,
            curve = _props.curve,
            _margin = _props.margin,
            _width = _props.width,
            _height = _props.height,
            axes = _props.axes,
            enableGridX = _props.enableGridX,
            enableGridY = _props.enableGridY,
            enableMarkers = _props.enableMarkers,
            markersSize = _props.markersSize,
            markersColor = _props.markersColor,
            markersBorderWidth = _props.markersBorderWidth,
            markersBorderColor = _props.markersBorderColor,
            _theme = _props.theme,
            colors = _props.colors,
            colorBy = _props.colorBy,
            animate = _props.animate,
            motionStiffness = _props.motionStiffness,
            motionDamping = _props.motionDamping;


        var margin = Object.assign({}, Nivo.defaults.margin, _margin);
        var width = _width - margin.left - margin.right;
        var height = _height - margin.top - margin.bottom;

        var theme = merge({}, defaultTheme, _theme);
        var color = getColorsGenerator(colors, colorBy);

        var motionProps = {
            animate: animate,
            motionDamping: motionDamping,
            motionStiffness: motionStiffness
        };

        var result = void 0;
        if (stacked === true) {
            result = generateStackedLines(data, width, height, color);
        } else {
            result = generateLines(data, width, height, color);
        }

        var lineGenerator = line().x(function (d) {
            return d.x;
        }).y(function (d) {
            return d.y;
        }).curve(curvePropMapping[curve]);

        var _result = result,
            xScale = _result.xScale,
            yScale = _result.yScale,
            lines = _result.lines;


        var markers = null;
        if (enableMarkers === true) {
            markers = React.createElement(LineMarkers, _extends({
                lines: lines,
                size: markersSize,
                color: getColorGenerator(markersColor),
                borderWidth: markersBorderWidth,
                borderColor: getColorGenerator(markersBorderColor)
            }, motionProps));
        }

        return React.createElement(
            SvgWrapper,
            { width: _width, height: _height, margin: margin },
            React.createElement(Grid, _extends({
                theme: theme,
                width: width,
                height: height,
                xScale: enableGridX ? xScale : null,
                yScale: enableGridY ? yScale : null
            }, motionProps)),
            React.createElement(Axes, _extends({
                axes: axes,
                xScale: xScale,
                yScale: yScale,
                width: width,
                height: height,
                theme: theme
            }, motionProps)),
            lines.map(function (_ref) {
                var id = _ref.id,
                    lineColor = _ref.color,
                    points = _ref.points;
                return React.createElement('path', {
                    key: id,
                    d: lineGenerator(points),
                    fill: 'none',
                    strokeWidth: 2,
                    stroke: lineColor
                });
            }),
            markers
        );
    };

    return Line;
}(Component);

Line.propTypes = _extends({
    // data
    data: PropTypes.arrayOf(PropTypes.shape({
        id: PropTypes.string.isRequired,
        data: PropTypes.arrayOf(PropTypes.shape({
            x: PropTypes.oneOfType([PropTypes.number, PropTypes.string]).isRequired,
            y: PropTypes.oneOfType([PropTypes.number, PropTypes.string]).isRequired
        })).isRequired
    })).isRequired,

    stacked: PropTypes.bool.isRequired,
    curve: curvePropType.isRequired,

    // dimensions
    width: PropTypes.number.isRequired,
    height: PropTypes.number.isRequired,
    margin: marginPropType,

    // axes
    axes: PropTypes.object.isRequired,
    enableGridX: PropTypes.bool.isRequired,
    enableGridY: PropTypes.bool.isRequired,

    // markers
    enableMarkers: PropTypes.bool.isRequired,
    markersSize: PropTypes.number.isRequired,
    markersColor: PropTypes.any.isRequired,
    markersBorderWidth: PropTypes.number.isRequired,
    markersBorderColor: PropTypes.any.isRequired,

    // theming
    theme: PropTypes.object.isRequired,
    colors: PropTypes.any.isRequired,
    colorBy: PropTypes.oneOfType([PropTypes.string, PropTypes.func])

}, motionPropTypes);
Line.defaultProps = {
    stacked: false,
    curve: 'linear',

    // dimensions
    margin: Nivo.defaults.margin,

    // axes
    axes: {
        left: {
            enabled: true
        },
        bottom: {
            enabled: true
        }
    },
    enableGridX: true,
    enableGridY: true,

    // markers
    enableMarkers: true,
    markersSize: 6,
    markersColor: 'inherit',
    markersBorderWidth: 0,
    markersBorderColor: 'inherit',

    // theming
    theme: {},
    colors: Nivo.defaults.colorRange,
    colorBy: 'id',

    // motion
    animate: true,
    motionStiffness: Nivo.defaults.motionStiffness,
    motionDamping: Nivo.defaults.motionDamping
};
export default Line;

==> nivo-0.6.0.tgz: package/es/components/charts/line/Line.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { merge } from 'lodash-es';
import { line } from 'd3-shape';
import Nivo, { defaultTheme } from '../../../Nivo';
import { margin as marginPropType, motion as motionPropTypes } from '../../../PropTypes';
import { getColorsGenerator, getColorGenerator } from '../../../ColorUtils';
import SvgWrapper from '../SvgWrapper';
import { generateLines, generateStackedLines } from '../../../lib/charts/line';
import { curvePropMapping, curvePropType } from '../../../properties/curve';
import Axes from '../../axes/Axes';
import Grid from '../../axes/Grid';
import LineMarkers from './LineMarkers';

var Line = function (_Component) {
    _inherits(Line, _Component);

    function Line() {
        _classCallCheck(this, Line);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    Line.prototype.render = function render() {
        var _props = this.props,
            data = _props.data,
            stacked = _props.stacked,
            curve = _props.curve,
            _margin = _props.margin,
            _width = _props.width,
            _height = _props.height,
            axes = _props.axes,
            enableGridX = _props.enableGridX,
            enableGridY = _props.enableGridY,
            enableMarkers = _props.enableMarkers,
            markersSize = _props.markersSize,
            markersColor = _props.markersColor,
            markersBorderWidth = _props.markersBorderWidth,
            markersBorderColor = _props.markersBorderColor,
            _theme = _props.theme,
            colors = _props.colors,
            colorBy = _props.colorBy,
            animate = _props.animate,
            motionStiffness = _props.motionStiffness,
            motionDamping = _props.motionDamping;


        var margin = Object.assign({}, Nivo.defaults.margin, _margin);
        var width = _width - margin.left - margin.right;
        var height = _height - margin.top - margin.bottom;

        var theme = merge({}, defaultTheme, _theme);
        var color = getColorsGenerator(colors, colorBy);

        var motionProps = {
            animate: animate,
            motionDamping: motionDamping,
            motionStiffness: motionStiffness
        };

        var result = void 0;
        if (stacked === true) {
            result = generateStackedLines(data, width, height, color);
        } else {
            result = generateLines(data, width, height, color);
        }

        var lineGenerator = line().x(function (d) {
            return d.x;
        }).y(function (d) {
            return d.y;
        }).curve(curvePropMapping[curve]);

        var _result = result,
            xScale = _result.xScale,
            yScale = _result.yScale,
            lines = _result.lines;


        var markers = null;
        if (enableMarkers === true) {
            markers = React.createElement(LineMarkers, _extends({
                lines: lines,
                size: markersSize,
                color: getColorGenerator(markersColor),
                borderWidth: markersBorderWidth,
                borderColor: getColorGenerator(markersBorderColor)
            }, motionProps));
        }

        return React.createElement(
            SvgWrapper,
            { width: _width, height: _height, margin: margin },
            React.createElement(Grid, _extends({
                theme: theme,
                width: width,
                height: height,
                xScale: enableGridX ? xScale : null,
                yScale: enableGridY ? yScale : null
            }, motionProps)),
            React.createElement(Axes, _extends({
                axes: axes,
                xScale: xScale,
                yScale: yScale,
                width: width,
                height: height,
                theme: theme
            }, motionProps)),
            lines.map(function (_ref) {
                var id = _ref.id,
                    lineColor = _ref.color,
                    points = _ref.points;
                return React.createElement('path', {
                    key: id,
                    d: lineGenerator(points),
                    fill: 'none',
                    strokeWidth: 2,
                    stroke: lineColor
                });
            }),
            markers
        );
    };

    return Line;
}(Component);

Line.propTypes = _extends({
    // data
    data: PropTypes.arrayOf(PropTypes.shape({
        id: PropTypes.string.isRequired,
        data: PropTypes.arrayOf(PropTypes.shape({
            x: PropTypes.oneOfType([PropTypes.number, PropTypes.string]).isRequired,
            y: PropTypes.oneOfType([PropTypes.number, PropTypes.string]).isRequired
        })).isRequired
    })).isRequired,

    stacked: PropTypes.bool.isRequired,
    curve: curvePropType.isRequired,

    // dimensions
    width: PropTypes.number.isRequired,
    height: PropTypes.number.isRequired,
    margin: marginPropType,

    // axes
    axes: PropTypes.object.isRequired,
    enableGridX: PropTypes.bool.isRequired,
    enableGridY: PropTypes.bool.isRequired,

    // markers
    enableMarkers: PropTypes.bool.isRequired,
    markersSize: PropTypes.number.isRequired,
    markersColor: PropTypes.any.isRequired,
    markersBorderWidth: PropTypes.number.isRequired,
    markersBorderColor: PropTypes.any.isRequired,

    // theming
    theme: PropTypes.object.isRequired,
    colors: PropTypes.any.isRequired,
    colorBy: PropTypes.oneOfType([PropTypes.string, PropTypes.func])

}, motionPropTypes);
Line.defaultProps = {
    stacked: false,
    curve: 'linear',

    // dimensions
    margin: Nivo.defaults.margin,

    // axes
    axes: {
        left: {
            enabled: true
        },
        bottom: {
            enabled: true
        }
    },
    enableGridX: true,
    enableGridY: true,

    // markers
    enableMarkers: true,
    markersSize: 6,
    markersColor: 'inherit',
    markersBorderWidth: 0,
    markersBorderColor: 'inherit',

    // theming
    theme: {},
    colors: Nivo.defaults.colorRange,
    colorBy: 'id',

    // motion
    animate: true,
    motionStiffness: Nivo.defaults.motionStiffness,
    motionDamping: Nivo.defaults.motionDamping
};
export default Line;
